\name{genSOAPClientInterface}
\alias{genSOAPClientInterface}
\title{Create R functions to access SOAP server methods}
\description{
  This function creates function definitions, etc. that provide
  access to the methods described in the SOAP server description
  details.  
}
\usage{
genSOAPClientInterface(operations = def@operations[[1]], def, name = def@name,
                       env = new.env(), where = globalenv(), server = def@server,
                       nameSpaces = def@nameSpaces, verbose = FALSE)
}
\arguments{
  \item{operations}{a list of the descriptions of the server's methods. Each method description 
     provides information about the parameters and the return value.}
  \item{def}{the \code{\link{SOAPServerDescription-class}} object.}
  \item{name}{currently unused }
  \item{env}{an environment object.  This is used ?}
  \item{where}{the location (usually in the search path) where new S4 classes will 
    be defined to represent the complex return types.  This can be any value that is acceptable for the
    \code{where} argument of \code{\link[methods]{setClass}}, i.e. 
     an integer, a package name (\dQuote{package:name}) or, explicitly, an environment.  }
   \item{server}{an object which will be used as the server in the SOAP
     calls. This provides the user with a mechanism to provide an
     alternative server object such as one which contains a password
     or which already has a connection to the SOAP server, or controls
     the connection in different ways.
   }
   \item{nameSpaces}{a character vector that identifies the
      namespace-URI mappings used for calls to this server.
      This maps the namespace abbreviations to the actual URIs.
      This can be a named character vector of these mappings, or
      alternatively a simple character string that identifies the name of
      the element in the \code{.SOAPDefaultNameSpaces} list.
      And if we don't know the collection of namespaces, we use
      \code{NA} to indicate that we shall determine this later.}
 \item{verbose}{a logical indicating whether information about the processing should be displayed on the console,
       as it occurs.}
}
\details{

}
\value{
}

\references{
  \url{http://www.w3.org/TR/SOAP/}
  \url{http://www.omegahat.org/SSOAP},
  \url{http://www.omegahat.org/bugs}.
}
\author{Duncan Temple Lang <duncan@wald.ucdavis.edu>}


\seealso{
 \code{\link{processWSDL}}
 }
\examples{
 kegg = processWSDL("http://soap.genome.jp/KEGG.wsdl")
   # note that we force the use of the 1.1 name spaces to get arrays
   # handled correctly on the server side.
 iface = genSOAPClientInterface(def = kegg, nameSpaces = "1.1")


 tmp = processWSDL(system.file("examples", "KEGG.wsdl", package = "SSOAP"))
 ff = genSOAPClientInterface(tmp@operations[[1]], def = tmp, tmp@name, verbose=FALSE)

 as.character.Definition = function(x)  structure(x[["definition"]], names = x[["entry_id"]])
 as.character.list = function(x) sapply(x, as.character)

 o = ff@functions$list_organisms()

 as.character.list(o)
}
\keyword{interface}
\keyword{programming}
